@@ -1,21 +1,19 @@
 """Tests for distutils.spawn."""
+
 import os
 import stat
 import sys
 import unittest.mock as mock
-
+from distutils.errors import DistutilsExecError
+from distutils.spawn import find_executable, spawn
+from distutils.tests import support
 from test.support import unix_shell
 
 import path
+import pytest
 
 from . import py38compat as os_helper
 
-from distutils.spawn import find_executable
-from distutils.spawn import spawn
-from distutils.errors import DistutilsExecError
-from distutils.tests import support
-import pytest
-
 
 class TestSpawn(support.TempdirManager):
     @pytest.mark.skipif("os.name not in ('nt', 'posix')")
@@ -53,7 +51,7 @@ class TestSpawn(support.TempdirManager):
         program = program_noeext + ".exe"
 
         program_path = tmp_path / program
-        program_path.write_text("")
+        program_path.write_text("", encoding='utf-8')
         program_path.chmod(stat.S_IXUSR)
         filename = str(program_path)
         tmp_dir = path.Path(tmp_path)
